@@ -52,6 +52,10 @@ biclustquest_WIN <- function(){     # Change newmethod to your own method name
 	
 	# Help Object
 	methodhelp <- "BCQuest"
+
+	# Extra
+	methodshow <- FALSE
+	methodsave <- FALSE
 	
 	# Possibility to give a seed ?
 	methodseed <- TRUE
@@ -576,7 +580,7 @@ biclustquest_WIN <- function(){     # Change newmethod to your own method name
 	## USE ALL THE ARGUMENTS ABOUT IN THE GENERAL CLUSTERTEMPLATE FUNCTION ##
 	#########################################################################
 	
-	cluster_template(methodname=methodname,methodfunction=methodfunction,methodhelp=methodhelp,data.arg=data.arg,other.arg=other.arg,methodseed=methodseed,grid.config=grid.config,grid.rows=grid.rows,new.frames=new.frames,superbiclust.comp=superbiclust.comp,bcdiag.comp=bcdiag.comp,data.discr=data.discr,data.bin=data.bin,extrabiclustplot=extrabiclustplot)
+	cluster_template(methodname=methodname,methodfunction=methodfunction,methodhelp=methodhelp,methodshow=methodshow,methodsave=methodsave,data.arg=data.arg,other.arg=other.arg,methodseed=methodseed,grid.config=grid.config,grid.rows=grid.rows,new.frames=new.frames,superbiclust.comp=superbiclust.comp,bcdiag.comp=bcdiag.comp,data.discr=data.discr,data.bin=data.bin,extrabiclustplot=extrabiclustplot)
 	
 }
 
